@@ -28,7 +28,7 @@ from mitosheet.updates.replay_analysis import REPLAY_ANALYSIS_UPDATE
 from mitosheet.user import is_local_deployment, should_upgrade_mitosheet
 from mitosheet.user.db import get_user_field
 from mitosheet.user.location import is_in_google_colab, is_in_vs_code
-from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES,
+from mitosheet.user.schemas import (UJ_MITOSHEET_LAST_FIFTY_USAGES, UJ_RECEIVED_CHECKLISTS,
                                     UJ_RECEIVED_TOURS, UJ_USER_EMAIL)
 from mitosheet.user.utils import is_excel_import_enabled, is_pro, is_running_test
 
@@ -94,6 +94,7 @@ class MitoWidget(DOMWidget):
             # Dynamic, update each time
             'userEmail': get_user_field(UJ_USER_EMAIL),
             'receivedTours': get_user_field(UJ_RECEIVED_TOURS),
+            'receivedChecklists': get_user_field(UJ_RECEIVED_CHECKLISTS),
             'isPro': is_pro(),
             'telemetryEnabled': telemetry_turned_on(),
             # Static over a single analysis
@@ -199,10 +200,14 @@ class MitoWidget(DOMWidget):
                 # NOTE: since API calls are in a seperate thread, their start time and end
                 # time are not valid, and so we don't even log the start time to not be confusing
                 start_time = None
+
             
-            # NOTE: we don't need to case on log_event above because it always gets
-            # passed to this function, and thus is logged.
-            log_event_processed(event, self.steps_manager, start_time=start_time)
+            if event['event'] != 'api_call':
+                # NOTE: we don't need to case on log_event above because it always gets
+                # passed to this function, and thus is logged. We also don't log in the
+                # case of an API event as that is in a seperate thread and so takes care
+                # of it's logging seperately
+                log_event_processed(event, self.steps_manager, start_time=start_time)
 
             return True
         except MitoError as e:
